TRFormValues class

Immutable snapshot of named Tinyrack form values.

Annotations

Constructors

TRFormValues(Map<String, Object?> values)

Properties

entries Iterable<MapEntry<String, Object?>>
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

contains(String name) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](String name) Object?