TRPaneHeader class

Shared title, description, and action chrome for one application pane.

Inheritance

Constructors

TRPaneHeader({required Widget title, Widget? description, Widget? leading, List<Widget> actions = const <Widget>[], double? contentMaxWidth, bool divider = true, Key? key})
const

Properties

actions List<Widget>
Actions associated with the entire pane.
final
contentMaxWidth double?
Optional maximum width for the header identity and action rail.
final
description Widget?
Optional supporting text rendered below title.
final
divider bool
Whether to separate the header from the pane body.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
leading Widget?
Optional content before the title group, such as a Back action.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title Widget
The pane's primary heading.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited