TRVirtualListInitialPosition<K> class

The position used when a virtual list has no restorable snapshot.

Annotations

Constructors

TRVirtualListInitialPosition.index(int itemIndex, {TRVirtualListAlignment alignment = TRVirtualListAlignment.leading})
const
TRVirtualListInitialPosition.key(K? key, {TRVirtualListAlignment alignment = TRVirtualListAlignment.leading})
const
TRVirtualListInitialPosition.leading()
const
TRVirtualListInitialPosition.trailing()
const

Properties

alignment TRVirtualListAlignment
final
hashCode int
The hash code for this object.
no setterinherited
index int?
final
key → K?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited