TRAppShell class
Responsive application chrome composed from typed Tinyrack shell parts.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- TRAppShell
Constructors
-
TRAppShell({required TRAppShellMain main, Map<
String, GlobalKey< anchorTargets = const {}, TRAppShellBreakpoint breakpoint = TRAppShellBreakpoint.lg, TRAppShellChrome chrome = TRAppShellChrome.app, TRAppShellController? controller, String? currentPath, bool defaultMobileOpen = false, TRAppShellSidebarMode defaultSidebarMode = TRAppShellSidebarMode.expanded, String hash = '', TRAppShellHeader? header, TRAppShellLayout layout = TRAppShellLayout.headerFirst, String loadingLabel = 'Loading page', String? locationKey, TRAppShellMobileDrawerSide mobileDrawerSide = TRAppShellMobileDrawerSide.start, TRAppShellMobileSidebar mobileSidebar = TRAppShellMobileSidebar.drawer, ValueChanged<State< >StatefulWidget> >bool> ? onMobileOpenChanged, ValueChanged<TRAppShellSidebarMode> ? onSidebarModeChanged, TRAppShellOutline? outline, TRAppShellPageScroll pageScroll = TRAppShellPageScroll.container, String? pendingPath, double railWidth = TRGeneratedLayerMetrics.appShellRailWidth, bool resizeToAvoidBottomInset = true, TRAppShellSidebar? sidebar, double sidebarWidth = TRGeneratedLayerMetrics.appShellSidebarWidth, Key? key}) -
const
Properties
-
anchorTargets
→ Map<
String, GlobalKey< State< >StatefulWidget> > -
final
- breakpoint → TRAppShellBreakpoint
-
final
- chrome → TRAppShellChrome
-
final
- controller → TRAppShellController?
-
final
- currentPath → String?
-
final
- defaultMobileOpen → bool
-
final
- defaultSidebarMode → TRAppShellSidebarMode
-
final
- hash → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- header → TRAppShellHeader?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- layout → TRAppShellLayout
-
final
- loadingLabel → String
-
final
- locationKey → String?
-
final
- main → TRAppShellMain
-
final
- mobileDrawerSide → TRAppShellMobileDrawerSide
-
final
- mobileSidebar → TRAppShellMobileSidebar
-
final
-
final
-
onMobileOpenChanged
→ ValueChanged<
bool> ? -
final
-
onSidebarModeChanged
→ ValueChanged<
TRAppShellSidebarMode> ? -
final
- outline → TRAppShellOutline?
-
final
- pageScroll → TRAppShellPageScroll
-
final
- pendingPath → String?
-
final
- railWidth → double
-
final
- resizeToAvoidBottomInset → bool
-
Whether the shell keeps its layout above the software keyboard.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
final
-
final
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< TRAppShell> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited