TRMultiComboboxController<T extends Object> class
Owns multiple combobox values and their shared query field.
- Inheritance
-
- Object
- ChangeNotifier
- TRMultiComboboxController
Constructors
-
TRMultiComboboxController({Iterable<
T> values = const []}) -
factory
Properties
- focusNode → FocusNode
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textEditingController → TextEditingController
-
final
-
values
→ List<
T> -
no setter
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
clear(
) → void -
dispose(
) → void -
Discards any resources used by the object.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
replace(
Iterable< T> values) → void -
toggle(
T value) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited