TRText class
Text rendered with a named Tinyrack typography role.
- Inheritance
Constructors
- TRText(String data, {TRTextVariant variant = TRTextVariant.body, TRTextColor? color, TRTextAlign? align, TRTextWeight? weight, bool truncate = false, int? maxLines, TextOverflow? overflow, bool? softWrap, Key? key})
-
const
- TRText.inherit(String data, {TRTextColor? color, TRTextAlign? align, TRTextWeight? weight, bool truncate = false, int? maxLines, TextOverflow? overflow, bool? softWrap, Key? key})
-
Text that keeps the ambient DefaultTextStyle instead of replacing it
with a typography role.
const
Properties
- align → TRTextAlign?
-
final
- color → TRTextColor?
-
final
- data → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- maxLines → int?
-
final
- overflow → TextOverflow?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- softWrap → bool?
-
final
- truncate → bool
-
Clips the text to one ellipsized line.
final
- variant → TRTextVariant?
-
The typography role, or
nullto inherit the ambient text style.final - weight → TRTextWeight?
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited